@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for kafka service client
 
@@ -7,16 +8,15 @@ Usage::
     import boto3
     from mypy_boto3_kafka import KafkaClient
 
-    session = boto3.Session()
-
     client: KafkaClient = boto3.client("kafka")
-    session_client: KafkaClient = session.client("kafka")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import IO, Any, Dict, List, Type, Union, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_kafka.paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
@@ -319,3 +319,6 @@ class KafkaClient:
         """
         [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
