@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for kafka service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_kafka import KafkaClient
-    from mypy_boto3_kafka import (
+    from mypy_boto3_kafka.paginator import (
         ListClusterOperationsPaginator,
         ListClustersPaginator,
         ListConfigurationRevisionsPaginator,
@@ -26,9 +27,10 @@ Usage::
     list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_kafka.type_defs import (
     ListClusterOperationsResponseTypeDef,
     ListClustersResponseTypeDef,
@@ -39,7 +41,6 @@ from mypy_boto3_kafka.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListClusterOperationsPaginator",
     "ListClustersPaginator",
